const fs = require('fs')
const Core = require('@nervosnetwork/ckb-sdk-core').default
const core = new Core()

const CKB_NODE_URL = 'https://mainnet.ckb.dev/rpc'

const exec = async () => {
  const tx = JSON.parse(fs.readFileSync('./tx.json', 'utf-8'))

  const transaction = {
    description: '',
    nervosDao: false,
    signatures: {},
    fee: '11205',
    ...tx,
  }

  const context = await fetch(CKB_NODE_URL, {
    method: 'POST',
    headers: {
      'Content-Type': 'application/json',
    },
    body: JSON.stringify(
      transaction.inputs.map((input, idx) => ({
        id: idx,
        jsonrpc: '2.0',
        method: 'get_transaction',
        params: [input.previousOutput.txHash],
      }))
    ),
  })
    .then((res) => res.json())
    .then((txs) => txs.map((txs) => txs.result.transaction))

  transaction.inputs.forEach((input, idx) => {
    const tx = context.find((t) => t.hash === input.previousOutput.txHash)
    if (!tx) {
      throw new Error(`Failed to load input cell ${idx} from context`)
    }
    const lock = tx.outputs[+input.previousOutput.index].lock
    console.log(lock)
    input.lock = {
      codeHash: lock.code_hash,
      hashType: lock.hash_type,
      args: lock.args,
    }
    input.lockHash = core.utils.scriptToHash(input.lock)
    // input.lockHash = core.utils.utils.computeScriptHash(input.lock)
  })

  const txToSign = {
    transaction,
    context,
    type: 'Regular',
    status: 'Unsigned',
  }
  fs.writeFileSync('./tx-to-sign.json', Buffer.from(JSON.stringify(txToSign)))
}

exec()
